@@ -2,8 +2,8 @@
 #'
 #' Prepares user provided reference regions on a country level
 #'
-#' @importFrom raster area
-#' @importFrom rworldmap getMap
+#' @importFrom sf st_area
+#' @importFrom rnaturalearth ne_countries
 #' @param  countries vector with one or more country names
 #' @param  biogeo_status vector informing the status of each country: alien, 
 #' native or unknown
@@ -19,10 +19,10 @@ countryChecklist <- function(countries, biogeo_status) {
   if (length(countries) != length(biogeo_status)) {
     stop("countries and biogeo_status have different lengths")
   }
-  world <- getMap()
+  world <- ne_countries(returnclass = "sf")
   features <- numeric()
   for (i in seq_along(countries)) {
-    a <- grep(countries[i], world$NAME)
+    a <- grep(countries[i], world$name_sort)
     if (length(a) == 0) {
       stop(paste0(countries[i], 
                   " was not found. Check  'availableCountries()'"))
@@ -33,13 +33,14 @@ countryChecklist <- function(countries, biogeo_status) {
     }
     features[i] <- a
   }
+  
   shp <- world[features, ]
   presence <- shp
-  presence$area <- area(presence)/1000000
+  presence$area <- as.numeric(st_area(presence)/1000000)
   native <- world[features[which(biogeo_status == "native")], ]
-  native$area <- area(native)/1000000
+  native$area <- as.numeric(st_area(native)/1000000)
   alien <- world[features[which(biogeo_status == "alien")], ]
-  alien$area <- area(alien)/1000000
+  alien$area <- as.numeric(st_area(alien)/1000000)
   
   range_list <- list(presence, native, alien)
   names(range_list) <- c("Presence", "Native", "Alien")
