@@ -5,9 +5,8 @@
 #' @importFrom graphics points par text
 #' @importFrom plotfunctions gradientLegend
 #' @importFrom raster extent plot
-#' @importFrom rgeos gIntersection gBuffer
-#' @importFrom rworldmap getMap
-#' @importFrom sp over proj4string
+#' @importFrom rnaturalearth ne_countries
+#' @importFrom sf st_as_sf st_intersects st_polygon st_sfc st_transform
 #' @importFrom grDevices colorRampPalette rgb
 #' @importFrom methods as
 #' @param acc dataTable of the species occurrence including a column with the 
@@ -33,23 +32,55 @@ plotAccuracy <- function(acc, regional = TRUE, reg.by = "country",
                          range = NULL, box = FALSE) {
   oldpar <- par(no.readonly = TRUE)
   on.exit(par(oldpar))
-  world <- getMap(resolution = "low")
-  world <- suppressWarnings(gBuffer(world, byid = TRUE, width = 0))
-  acc_sp <- occSpatialPoints(acc)
+  world <- ne_countries(returnclass = "sf")
+  old_proj <- crs(world)
+  world <- st_transform(world, crs = 3857)
+
+  acc_sf <- st_as_sf(acc, coords = c('decimalLongitude', 'decimalLatitude'),
+                     crs = old_proj)
+  acc_sf <- st_transform(acc_sf, crs = 3857)
+  
   if(regional){
     if(reg.by=="country"){
-      countries <- unique(over(acc_sp,world)$NAME)
-      countries <- world[world$NAME %in% countries,]
-      CP <- as(extent(countries), "SpatialPolygons")
-      sp::proj4string(CP) <- CRS(proj4string(world))
-      map <- suppressWarnings(gIntersection(world, CP, byid = TRUE, 
-                                            checkValidity = 2))
+      
+      countries <- unique(vapply(st_intersects(acc_sf,world), 
+                  function(x) if (length(x)==0) NA_integer_ else x[1],
+                  FUN.VALUE = 1))
+      
+      if(length(which(is.na(countries))) == 1){
+        countries <-  countries[-which(is.na(countries))]
+      }
+                
+      countries <- world[countries,]
+
+      coords_CP <- extent(countries)
+      
+      CP <- st_polygon(list(cbind(
+          c(coords_CP[1],coords_CP[2],coords_CP[2],coords_CP[1],coords_CP[1]),
+          c(coords_CP[3],coords_CP[3],coords_CP[4],coords_CP[4],coords_CP[3]))))
+      
+      CP <- st_sfc(CP, crs = crs(world))
+      CP <- st_as_sf(CP)
+      
+      map <- suppressWarnings(st_intersection(world, CP))
     }
+    
     if (reg.by == "points") {
-      CP <- as(extent(acc_sp) + c(-1.5, 1.5, -1.5, 1.5), "SpatialPolygons")
-      sp::proj4string(CP) <- CRS(proj4string(world))
-      map <- suppressWarnings(gIntersection(world, CP, byid = TRUE, 
-                                            checkValidity = 2))
+      coords_CP <- extent(acc_sf)
+      
+      x_marge <- (coords_CP[2] - coords_CP[1]) * 0.05
+      y_marge <- (coords_CP[4] - coords_CP[3]) * 0.05
+      
+      CP <- st_polygon(list(cbind(
+        c(coords_CP[1],coords_CP[2],coords_CP[2],coords_CP[1],coords_CP[1]) +
+          c(-x_marge, x_marge, x_marge, -x_marge, -x_marge),
+        c(coords_CP[3],coords_CP[3],coords_CP[4],coords_CP[4],coords_CP[3]) +
+          c(-y_marge, -y_marge, y_marge, y_marge, -y_marge))))
+      
+      CP <- st_sfc(CP, crs = crs(world))
+      CP <- st_as_sf(CP)
+      
+      map <- suppressWarnings(st_intersection(world, CP))
     }
   } else {
     map <- world
@@ -65,15 +96,20 @@ plotAccuracy <- function(acc, regional = TRUE, reg.by = "country",
     bord <- NA
   }
   
+  map <- st_transform(map, crs = old_proj)
+  
   par(mfrow = c(1, 1), mar = c(1.5, 1.5, 1.5, 5))
-  plot(map, col = col.features, bg = col.bg, border = bord,
+  plot(st_geometry(map), col = col.features, bg = col.bg, border = bord,
        main = unique(acc$species), font.main = 3)
   
   if (plot.range) {
-    plot(range, add = TRUE, border = NA, col = "#1c9099")
+    range <- st_as_sf(range, crs = old_proj)
+    plot(st_geometry(range), add = TRUE, border = NA, col = "#1c9099")
   }
   
   if (box) {
+    CP <- st_transform(CP, crs = old_proj)
+    
     plot(CP, add = TRUE)
     points((extent(CP)[1] + extent(CP)[2])/2, extent(CP)[3], pch = 3, 
            cex = 0.8)
@@ -96,5 +132,7 @@ plotAccuracy <- function(acc, regional = TRUE, reg.by = "country",
                    side = 4, color = colacc(20), n.seg = 3)
   }
   
-  points(acc_sp, pch = 21, cex = 1, bg = col_pts_acc)
+  acc_sf <- st_transform(acc_sf, crs = old_proj)
+  
+  plot(st_geometry(acc_sf), add = T, pch = 21, cex = 1, bg = col_pts_acc) 
 }
